@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 
-$CPAN::Reporter::VERSION = "0.46"; 
+$CPAN::Reporter::VERSION = '0.48'; 
 
 use Config;
 use Config::Tiny ();
@@ -492,8 +492,10 @@ my @env_vars= qw(
     SHELL
     COMSPEC
     TERM
+    TEMP
+    TMPDIR
     AUTOMATED_TESTING
-    AUTHOR_TESTING
+    /AUTHOR_TEST/
     INCLUDE
     LIB
     LD_LIBRARY_PATH
