@@ -60,7 +60,7 @@ sub test_fake_config {
     mkpath $config_dir;
     ok( -d $config_dir,
         "config directory created"
-    );
+    ) or die "Error creating config directory: $!\n";
 
     my $tiny = Config::Tiny->new();
     $tiny->{_}{email_from} = $bogus_email_from;
@@ -82,7 +82,7 @@ sub test_fake_config {
 # dist tests
 #--------------------------------------------------------------------------#
 
-sub test_dist_plan() { 1 + _test_dist_eumm_plan() + _test_dist_mb_plan() }
+sub test_dist_plan() { 2 + _test_dist_eumm_plan() + _test_dist_mb_plan() }
 sub test_dist {
     my ($case, $dist) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -101,11 +101,14 @@ sub test_dist {
     );
     ok( dircopy($dist_dir, $work_dir),
         "Copying $case->{name} to temporary build directory"
-    );
-
-    my $pushd = pushd $work_dir;
+    ) or diag $!;
 
+    my $pushd = pushd $work_dir; # dies on failure
+    my $cur_dir = File::Spec->rel2abs(File::Spec->curdir());
     _test_dist_eumm( $case, $dist );
+    is( File::Spec->rel2abs(File::Spec->curdir()), $cur_dir, 
+        "Still in temporary directory" 
+    );
     _test_dist_mb( $case, $dist );
 
 }
@@ -127,75 +130,86 @@ sub _test_dist_eumm {
     $t::Helper::sent_report = undef;
     @t::Helper::cc_list = ();
 
-    eval {
-        capture sub {
-            # Have to run Makefile separate as return value isn't reliable
-            $makefile_rc = ! system("$perl Makefile.PL");
-            $test_make_rc = CPAN::Reporter::test( $dist, "$make test" );
-        }, \$stdout, \$stderr;
-        return 1;
-    } or diag "$@\n\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
-     
-    ok( $makefile_rc,
-        "$case->{name}: Makefile.PL ran without error"
-    ); 
+    SKIP: {
+        eval {
+            capture sub {
+                # Have to run Makefile separate as return value isn't reliable
+                $makefile_rc = ! system("$perl Makefile.PL");
+            }, \$stdout, \$stderr;
+            return 1;
+        } or diag "$@\n\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
+         
+        ok( $makefile_rc,
+            "$case->{name}: Makefile.PL ran without error"
+        ) or diag "\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
 
-    my $is_rc_correct = $case->{eumm_success} ? $test_make_rc : ! $test_make_rc;
+        skip "Couldn't build Makefile", _test_dist_eumm_plan() - 1
+            if !$makefile_rc;
 
-    ok( $is_rc_correct, 
-        "$case->{name}: test('make test') returned $case->{eumm_success}"
-    );
-    
-    my $is_grade_correct;
-    # Special case if discarding
-    if ( $case->{eumm_grade} eq 'discard' ) {
-        $is_grade_correct = 
-            $stdout =~ /Test results were not valid/ms;
+        eval {
+            capture sub {
+                $test_make_rc = CPAN::Reporter::test( $dist, "$make test" );
+            }, \$stdout, \$stderr;
+            return 1;
+        } or diag "$@\n\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
+         
+        my $is_rc_correct = $case->{eumm_success} ? $test_make_rc : ! $test_make_rc;
 
-        ok( $is_grade_correct,
-            "$case->{name}: test('make test') prerequisites not satisifed"
-        );
-            
-        like( $stdout, 
-            "/Test results for $dist->{short_name} will be discarded/",
-            "$case->{name}: discard message correct"
-        );
-
-        ok( ! defined $t::Helper::sent_report,
-            "$case->{name}: test results discarded"
-        );
-    }
-    else {
-        $is_grade_correct = 
-            $stdout =~ /^Test result is '$case->{eumm_grade}'/ms;
-
-        ok( $is_grade_correct, 
-            "$case->{name}: test('make test') grade reported as '$case->{eumm_grade}'"
-        );
-            
-        like( $stdout, "/Preparing a test report for $dist->{short_name}/",
-            "$case->{name}: report info header correct"
+        ok( $is_rc_correct, 
+            "$case->{name}: test('make test') returned $case->{eumm_success}"
         );
         
-        if ( -r $config_file ) {
-            ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
-                "$case->{name}: test report was mock sent"
+        my $is_grade_correct;
+        # Special case if discarding
+        if ( $case->{eumm_grade} eq 'discard' ) {
+            $is_grade_correct = 
+                $stdout =~ /Test results were not valid/ms;
+
+            ok( $is_grade_correct,
+                "$case->{name}: test('make test') prerequisites not satisifed"
+            );
+                
+            like( $stdout, 
+                "/Test results for $dist->{short_name} will be discarded/",
+                "$case->{name}: discard message correct"
+            );
+
+            ok( ! defined $t::Helper::sent_report,
+                "$case->{name}: test results discarded"
             );
         }
         else {
-            ok( ! defined $t::Helper::sent_report,
-                "$case->{name}: test results not sent"
+            $is_grade_correct = 
+                $stdout =~ /^Test result is '$case->{eumm_grade}'/ms;
+
+            ok( $is_grade_correct, 
+                "$case->{name}: test('make test') grade reported as '$case->{eumm_grade}'"
+            );
+                
+            like( $stdout, "/Preparing a test report for $dist->{short_name}/",
+                "$case->{name}: report info header correct"
             );
-        }
             
+            if ( -r $config_file ) {
+                ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
+                    "$case->{name}: test report was mock sent"
+                );
+            }
+            else {
+                ok( ! defined $t::Helper::sent_report,
+                    "$case->{name}: test results not sent"
+                );
+            }
+                
+        }
+
+        like( $stdout, "/$case->{eumm_msg}/",
+            "$case->{name}: test('make test') grade explanation correct"
+        );
+
+        diag "STDOUT:\n$stdout\n\nSTDERR:\n$stderr\n" 
+            unless ( $is_rc_correct && $is_grade_correct );
     }
-
-    like( $stdout, "/$case->{eumm_msg}/",
-        "$case->{name}: test('make test') grade explanation correct"
-    );
-
-    diag "STDOUT:\n$stdout\n\nSTDERR:\n$stderr\n" 
-        unless ( $is_rc_correct && $is_grade_correct );
 }
 
 #--------------------------------------------------------------------------#
@@ -218,15 +232,29 @@ sub _test_dist_mb {
         $t::Helper::sent_report = undef;
         @t::Helper::cc_list = ();
 
-        capture sub {
-            $build_rc = do "Build.PL";
-            $test_build_rc = CPAN::Reporter::test( $dist, "$perl Build test" );
-        }, \$stdout, \$stderr;
-
+        eval {
+            capture sub {
+                # Have to run Makefile separate as return value isn't reliable
+                $build_rc = ! system("$perl Build.PL");
+            }, \$stdout, \$stderr;
+            return 1;
+        } or diag "$@\n\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
+         
         ok( $build_rc,
             "$case->{name}: Build.PL returned true"
         ); 
         
+        skip "Couldn't create Build", _test_dist_mb_plan() - 1
+            if !$build_rc;
+
+        eval {
+            capture sub {
+                $test_build_rc = CPAN::Reporter::test( $dist, "$perl Build test" );
+            }, \$stdout, \$stderr;
+            return 1;
+        } or diag "$@\n\nSTDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
+         
+
         my $is_rc_correct = $case->{mb_success} ? $test_build_rc : ! $test_build_rc;
 
         ok( $is_rc_correct, 
